p.peasy-datalist-errors {
    color: red;
}

.peasy-datalist-container {
    border: 1px solid #ced4da;
    border-radius: .25rem;
    padding: 0.5rem;
}

.peasy-flex-row {
    display: flex;
    flex-direction: row;
    max-width: 100%;
}

.peasy-flex-col {
    display: flex;
    flex-direction: column;
}

.peasy-red {
    color: #fff;
    background-color: #dc3545;
    border-color: #dc3545;
}

.peasy-red:hover {
    color: #fff;
    background-color: #c82333;
    border-color: #bd2130;
}

input.peasy-datalist-selected {
    flex-grow: 1;
    display: block;
    padding: 0;
    padding-top: 0.25rem;
    padding-left: 0.5rem;
    margin-left: 0.5rem;
    font-size: 0.8rem;
    line-height: 1.5;
    color: #495057;
    background-color: rgb(237, 237, 255);
    background-clip: padding-box;
    border: 1px solid #ced4da;
    border-radius: .25rem;
}

.peasy-datalist-selected-box {
    overflow-y: auto;
    margin-top: 0;
    max-height: 12rem;
    padding-right: 0.5rem;
}

button.peasy-datalist-rm-btn {
    height: 1.5rem;
    width: 1.5rem;
    padding: 0;
    border-radius: 100%;
    cursor: pointer;
    margin-top: auto;
    margin-bottom: auto;
    margin-left: 0.5rem;
    text-align: center;
}

button.peasy-datalist-rm-btn>svg {
    display: block;
    margin: auto;
}

input.peasy-datalist-input {
    cursor: default;
}